# Graphics and Sound

Windows Git can load graphics and sound resources either from within Blorb files or as separate files.

If a Blorb file is loaded into the interpreter, or a Blorb file exists with the same name as the Glulx game file, then graphics and sound resources will be looked for first in that Blorb file.

If Windows Git cannot find a requested resource in the Blorb file (or there is no Blorb file), it will look for a suitably named file in the same directory as the game file. The resource formats currently supported are shown below, along with the filename for which the interpreter will look if the resource is not in the Blorb file (as an example, the filename is for resource number 1):

> Format | Type | Example Filename
> PNG | image | pic1.png
> JPEG | image | pic1.jpg
> AIFF | sound | snd1.aif or snd1.aiff
> MOD | music | mus1.mod
> OGGV | music | mus1.ogg